import { __extends } from "tslib";
import { EVENT } from '../../../constants';
import { I18n, EXIT_FULL_SCREEN, FULL_SCREEN } from '../../../features/i18n';
import { Icon } from '../../../features/icons';
import { addDispose, addDisposeListener } from '../../../utils/dispose';
import { hide, show } from '../../../utils/dom';
import { DomNode } from '../../../utils/domNode';
var Fullscreen = /** @class */ (function (_super) {
    __extends(Fullscreen, _super);
    function Fullscreen() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.id = 'fullscreen';
        _this.enter = function () {
            show(_this.exitIcon);
            hide(_this.enterIcon);
            _this.tooltip.html = I18n.trans(EXIT_FULL_SCREEN);
            if (_this.mounted) {
                _this.player.updateControllerEles(_this.player.options.controller.eles.filter(function (ele) { return ele !== 'web-fullscreen'; }), 'eles');
            }
        };
        _this.exit = function () {
            hide(_this.exitIcon);
            show(_this.enterIcon);
            _this.tooltip.html = I18n.trans(FULL_SCREEN);
            if (_this.mounted) {
                _this.player.updateControllerEles(_this.player.options.controller.eles, 'eles');
            }
        };
        return _this;
    }
    Fullscreen.prototype.init = function (player, tooltip) {
        this.player = player;
        this.tooltip = tooltip;
        this.enterIcon = this.el.appendChild(Icon.enterFullscreen());
        this.exitIcon = this.el.appendChild(Icon.exitFullscreen());
        if (player.fullscreen.isActive) {
            this.enter();
        }
        else {
            this.exit();
        }
        addDispose(this, player.on(EVENT.ENTER_FULLSCREEN, this.enter));
        addDispose(this, player.on(EVENT.EXIT_FULLSCREEN, this.exit));
        addDisposeListener(this, this.el, 'click', function () { return player.fullscreen.toggle(true); });
    };
    return Fullscreen;
}(DomNode));
export var fullscreenControllerEle = function () { return new Fullscreen(); };
//# sourceMappingURL=fullscreen.js.map